@@ -11,7 +11,7 @@ use Bio::Gonzales::Feat::IO::GFF3;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.0547_01'; # VERSION
+our $VERSION = 0.01_01;
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
@@ -28,7 +28,7 @@ sub gffiterate {
     my $feat = $gff->next_feat;
 
     unless ( defined($feat) ) {
-      $fh->close unless ($fh_was_open);
+      close $fh unless ($fh_was_open);
       return;
     }
     return $feat;
