@@ -14,7 +14,7 @@ use Bio::Gonzales::Seq::IO qw(faiterate faspew);
 
 use Params::Validate qw/validate/;
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.0547_01'; # VERSION
+our $VERSION = 0.01_01;
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
@@ -43,7 +43,7 @@ sub makeblastdb {
     while ( my $s = $fait->() ) {
       faspew( $fh, $s );
     }
-    $fh->close;
+    close $fh;
     $unlink = 1;
     $seqf   = $fn;
     say STDERR "extraction finished. making blast DB";
@@ -55,10 +55,10 @@ sub makeblastdb {
   push @cmd, '-title', $basename;
   push @cmd, '-parse_seqids' if ( $c{parse_seqids} );
   push @cmd, '-hash_index'   if ( $c{hash_index} );
-
-  if    ( $c{alphabet} =~ /^(?:a|p)/ )   { push @cmd, '-dbtype', 'prot' }
-  elsif ( $c{alphabet} =~ /^(?:n|d|r)/ ) { push @cmd, '-dbtype', 'nucl' }
-
+  given ( $c{alphabet} ) {
+    when (/^(?:a|p)/)   { push @cmd, '-dbtype', 'prot' }
+    when (/^(?:n|d|r)/) { push @cmd, '-dbtype', 'nucl' }
+  }
   $c{wd} //= './';
   $c{db_prefix} //= $basename;
   $c{db_prefix} .= '.bdb';
